==> atmos-2.96.9.tar.gz: atmos-2.96.9/src/file_input.h <==
/*
    $Id: file_input.h 142 2010-04-03 13:50:39Z matwey $
    Copyright (C) 2009  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _FILE_INPUT_H
#define _FILE_INPUT_H

#include <iosfwd>
#include <stdexcept>
#include <string>

#include <boost/algorithm/string.hpp>
#include <boost/date_time/posix_time/posix_time.hpp>

#include <boost/numeric/ublas/vector.hpp>
#include <boost/numeric/ublas/symmetric.hpp>

#include "io.h"

using namespace boost::numeric;

class file_input {
public:
	typedef size_t size_type;
	
	typedef boost::posix_time::ptime time_type;
	typedef ublas::vector<double>    flux_type;
	typedef ublas::symmetric_matrix<double> vars_type;
	typedef ublas::symmetric_matrix<double> rho1_type;
	typedef ublas::vector<double>    rho2_type;
	typedef object                   object_type;

	typedef ublas::vector<double>    dimm_flux_type;
	typedef ublas::vector<double>    dimm_vars_type;
private:
	size_type m_linenum;
	std::istream& m_stm;
	std::string m_line;
	bool m_cached;
	std::locale m_locale;
	private:
	
	static std::string strip_spaces( const std::string& str );

	void parse_line( size_type linenum, const std::string& line );
	void parse_comment_line( std::istringstream& stm );
	void parse_param_line( std::istringstream& stm );
	void parse_object_line( std::istringstream& stm );
	void parse_mode_line( std::istringstream& stm );
	void parse_measurement_line( std::istringstream& stm );
	void parse_dimm_line( std::istringstream& stm );

protected:
	bool unshift() throw();
public:
	class failure:
		public std::runtime_error {
	public:
		failure( const std::string& what );
	};
public:
	file_input( std::istream& stm );
	virtual ~file_input();

	bool shift();

	size_type line() const throw() ;
public:
	virtual void on_comment( const std::string& line ) = 0;
	virtual void on_parameter( const time_type& time, const std::string& key, const std::string& value ) = 0;
	virtual void on_object( const time_type& time, const object_type& obj ) = 0;
	virtual void on_background( const time_type& time ) = 0;
	virtual void on_normal( const time_type& time ) = 0;
	virtual void on_flux( const time_type& time ) = 0;
	virtual void on_measurements( const time_type& time, const flux_type& mean, const vars_type& vars, const rho1_type& rho1, const rho2_type& rho2 ) = 0;
	virtual void on_dimm( const time_type& time, unsigned int framenum, const dimm_flux_type& left, const dimm_flux_type& right, const dimm_vars_type& xvars, const dimm_flux_type& yvars ) = 0;
};

#endif // _FILE_INPUT_H

==> atmos-2.97.12.tar.gz: atmos-2.97.12/src/file_input.h <==
/*
    $Id: file_input.h 301 2017-04-26 07:39:45Z matwey $
    Copyright (C) 2009  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _FILE_INPUT_H
#define _FILE_INPUT_H

#include <iosfwd>
#include <stdexcept>
#include <string>

#include <boost/date_time/posix_time/posix_time.hpp>
#include <boost/numeric/ublas/symmetric.hpp>
#include <boost/numeric/ublas/vector.hpp>

#include "atmos.h" // size_type
#include "typesdef.h" // object

namespace atmos {
namespace input {

using namespace boost::numeric::ublas;

typedef boost::posix_time::ptime time_type;
typedef double               value_type;
typedef vector< value_type > vector_type;
typedef symmetric_matrix< value_type > symmetric_matrix_type;

typedef vector_type flux_type;
typedef symmetric_matrix_type vars_type;
typedef symmetric_matrix_type rho1_type;
typedef vector_type rho2_type;
typedef vector_type dimm_flux_type;
typedef vector_type dimm_vars_type;
typedef object object_type;

class file {
public:
	typedef atmos::size_type        size_type;
	typedef atmos::input::time_type time_type;
	typedef atmos::input::flux_type flux_type;
	typedef atmos::input::vars_type vars_type;
	typedef atmos::input::rho1_type rho1_type;
	typedef atmos::input::rho2_type rho2_type;
	typedef atmos::input::dimm_flux_type dimm_flux_type;
	typedef atmos::input::dimm_vars_type dimm_vars_type;
	typedef atmos::input::object_type object_type;
private:
	size_type m_linenum;
	std::istream& m_stm;
	std::string m_line;
	bool m_cached;
	std::locale m_locale;
private:
	static std::string strip_spaces( const std::string& str );

	void parse_line( size_type linenum, const std::string& line );
	void parse_comment_line( std::istringstream& stm );
	void parse_param_line( std::istringstream& stm );
	void parse_object_line( std::istringstream& stm );
	void parse_mode_line( std::istringstream& stm );
	void parse_measurement_line( std::istringstream& stm );
	void parse_dimm_line( std::istringstream& stm );
protected:
	bool unshift() throw();
public:
	class failure:
		public std::runtime_error {
	public:
		failure( const std::string& what );
	};
public:
	file( std::istream& stm );
	virtual ~file();

	bool shift();
	size_type line() const throw() ;
public:
	virtual void on_comment( const std::string& line ) = 0;
	virtual void on_parameter( const time_type& time, const std::string& key, const std::string& value ) = 0;
	virtual void on_object( const time_type& time, const object_type& obj ) = 0;
	virtual void on_background( const time_type& time ) = 0;
	virtual void on_normal( const time_type& time ) = 0;
	virtual void on_flux( const time_type& time ) = 0;
	virtual void on_unknown_mode( const time_type& time ) = 0;
	virtual void on_measurements( const time_type& time, const flux_type& mean, const vars_type& vars, const rho1_type& rho1, const rho2_type& rho2 ) = 0;
	virtual void on_dimm( const time_type& time, unsigned int framenum, const dimm_flux_type& left, const dimm_flux_type& right, const dimm_vars_type& xvars, const dimm_flux_type& yvars ) = 0;
};

}}

#endif // _FILE_INPUT_H
